"""remove an agency from GTFS if no routes are present that use that agency
"""
import sys, os, shutil
import mzgtfs.feed
import mzgtfs.util
import util


def main(argv):
    if len(argv) < 2:
        print "usage: simple_agency_remove.py gtfs_file"
        sys.exit(0)

    files = ['agency.txt']

    gtfs_file = argv[1]

    f = mzgtfs.feed.Feed(gtfs_file)
    
    agencies_in_routes = set((r.get('agency_id') for r in f.routes()))

    for a in f.agencies():
        if a.id() not in agencies_in_routes:
          f.by_id['agency'].pop(a.id())

    f.write('agency.txt', f.agencies())
    f.make_zip('output.zip', files=files, clone=gtfs_file)
    shutil.move('output.zip', gtfs_file)
    util.delete_temp_files(files)
    
if __name__ == "__main__":
   main(sys.argv)


#!/usr/bin/python
""" update route_id to specified route_id
Usage: rename_route_id.py <original_route_id> <new_route_id>
"""
import sys, os, shutil
import mzgtfs.feed
import mzgtfs.util
import util

def rename_route_id(gtfs_feed, gtfs_file, original_route_id, new_route_id):
    files = ['trips.txt', 'routes.txt']

    util.delete_temp_files(files)

    for t in gtfs_feed.trips():
        if t.get('route_id') == original_route_id:
            t.set('route_id', new_route_id)

    for r in gtfs_feed.routes():
        if r.get('route_id') == original_route_id:
            gtfs_feed.by_id['routes'].pop(original_route_id)

    gtfs_feed.write('trips.txt', gtfs_feed.trips())
    gtfs_feed.write('routes.txt', gtfs_feed.routes())
    gtfs_feed.make_zip('output.zip', files=files, clone=gtfs_file)
    shutil.move('output.zip', gtfs_file)
    util.delete_temp_files(files)


def main(argv):
    if len(argv) < 3:
        print "Usage: rename_route_id.py <original_route_id> <new_route_id>"
        sys.exit(0)

    original_route_id = argv[2]
    new_route_id = argv[3] 

    gtfs_file = argv[1]
    gtfs_feed = mzgtfs.feed.Feed(filename=gtfs_file)
    
    try:
        rename_route_id(gtfs_feed, gtfs_file, original_route_id, new_route_id)

    except Exception as e:
        print(repr(e))


if __name__ == "__main__":
   main(sys.argv)


#!/usr/bin/python
"""Prepend agency ID to all routes, trips and stops in a GTFS
"""

import mzgtfs.feed
import mzgtfs.util
import sys, os

gtfs_file = sys.argv[1]
if len(sys.argv) > 1:
    replacement_agency_id = sys.argv[2]

gtfs_feed = mzgtfs.feed.Feed(filename=gtfs_file)
gtfs_feed.preload()
files = ["routes.txt", "trips.txt", "stops.txt"]

agency_id = gtfs_feed.agencies()[0].id()

if replacement_agency_id:
    agency_id = replacement_agency_id 

for stop in gtfs_feed.stops():
    new_stop_id = agency_id + '_' + stop.id()
    stop.set('stop_id',new_stop_id)

for route in gtfs_feed.routes():
    new_route_id = agency_id + '_' + route.id()
    route.set('route_id',new_route_id)

for trip in gtfs_feed.trips():
    new_route_id = agency_id + '_' + trip.get('route_id')
    trip.set('route_id',new_route_id)

for f in files:
    if os.path.exists(f):
        os.remove(f)

gtfs_feed.write('routes.txt', gtfs_feed.routes())
gtfs_feed.write('trips.txt', gtfs_feed.trips())
gtfs_feed.write('stops.txt', gtfs_feed.stops())

gtfs_feed.make_zip(gtfs_file + ".new", files=files, clone=gtfs_file)


#!/usr/bin/python
"""Add a feed_info with feed_id to the gtfs
usage: add_feed_id.py gtfs_file <optional replacement feed_id> <boolean to replace agency_id with new feed_id>"""

import sys, os, shutil
import mzgtfs.feed
import mzgtfs.util
import util


def add_feed_id(gtfs_feed, gtfs_file, feed_id = None, new_agency_id_bool = False):
    files = ["feed_info.txt"]
    util.delete_temp_files(files)

    if len(gtfs_feed.agencies()) > 1 and new_agency_id_bool is True:
        raise ValueError('cannot replace agency_id when there is more than one agency')

    agency_id = gtfs_feed.agencies()[0].id()
    url = gtfs_feed.agency(agency_id).get('agency_url')
    lang = gtfs_feed.agency(agency_id).get('agency_lang')
    feed_id = feed_id or agency_id

    print "adding feed_id " + feed_id +" to " + gtfs_file
        
    if lang: 
        feed_lang = lang
    else:
        feed_lang = 'en'

    if new_agency_id_bool:
        gtfs_feed.agency(agency_id).set('agency_id', feed_id)
        agency_id = feed_id

        files.append('agency.txt')
        files.append('routes.txt')

        gtfs_feed.write('agency.txt', gtfs_feed.agencies())
        
        for r in gtfs_feed.routes():
            r.set('agency_id', feed_id)
        gtfs_feed.write('routes.txt', gtfs_feed.routes())
    else:
        pass

    if 'feed_info' not in gtfs_feed.by_id:
        gtfs_feed.by_id['feed_info'] = {}
        cls = gtfs_feed.FACTORIES['feed_info']
        info = cls.from_row({
            'feed_publisher_name' : agency_id,
            'feed_publisher_url' : url ,
            'feed_lang' : feed_lang,
            'feed_id' : feed_id
            })
        gtfs_feed.by_id['feed_info']['a'] = info


    gtfs_feed.write('feed_info.txt', gtfs_feed.feed_infos())
    gtfs_feed.make_zip('output.zip', files=files, clone=gtfs_file)
    shutil.move('output.zip', gtfs_file)
    util.delete_temp_files(files)
    

def main(gtfs_file, feed_id, new_agency_id_bool=False):

    gtfs_feed = mzgtfs.feed.Feed(filename=gtfs_file)
    
    try:
        add_feed_id(gtfs_feed, gtfs_file, feed_id, new_agency_id_bool)

    except Exception as e:
        print(repr(e))


if __name__ == "__main__":
   import plac
   plac.call(main)



#!/usr/bin/env python

from setuptools import setup

setup(name='mzgtfs-tools',
      version='0.1.1',
      description='tools using mapzen-gtfs library',
      author='Tony Laidig',
      author_email='laidig@gmail.com',
      url='https://github.com/BusTechnology/mzgtfs-tools',
      packages=['mzgtfs-tools'],
      install_requires=[
          'plac==0.9.6', 
          'mzgtfs'
          ],
      dependency_links = [
          'http://github.com/BusTechnology/mapzen-gtfs.git#egg=mzgtfs-tools'
      ],
      license='Apache',
      classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: Apache Software License',
        'Programming Language :: Python :: 2.7'
    ]
)
